/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.stock.api;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JToolBar;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.windows.TopComponent;

/**
 * Displays overview of the Stock
 * 
 * @author Timon Veenstra <monezz@gmail.com>
 */
@MultiViewElement.Registration(displayName = "#Label_stock_overview_panel",
iconBase = Stock.STOCK_ICON16,
mimeType = Stock.MIME_TYPE,
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "StockOverview",
position = 100)
@NbBundle.Messages("Label_stock_overview_panel=Overview")
public class StockOverviewElement  implements MultiViewElement, PropertyChangeListener{
  
    private static final long serialVersionUID = 1L;
    private JToolBar toolbar = new JToolBar();
    private final ASBodyPanel content;
    private final Lookup lookup;
    private MultiViewElementCallback callback;    
    
    public StockOverviewElement(Lookup lookup) {
        this.lookup = lookup;
        content = new ASBodyPanel(new StockOverviewPanel());
        content.setIcon(ImageUtilities.loadImageIcon(Stock.STOCK_ICON32, true));
        content.setTitle(Bundle.Label_stock_overview_panel());
    }

    @Override
    public JComponent getVisualRepresentation() {
        return content;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return lookup;
    }

    @Override
    public void componentOpened() {
    }

    @Override
    public void componentClosed() {
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }

    @Override
    public void propertyChange(PropertyChangeEvent evt) {
    }

    public void updateName() {
        if (callback != null) {
            //TODO name should come from a stock object, but nothing to store in it just jet
            String name = Bundle.Label_stock_overview_panel();
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(name);
            tc.setDisplayName(name);
            tc.setName(content.getName());
            tc.setToolTipText(content.getToolTipText());
        }
    }    
}
