/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.stock.api;

import java.awt.Image;
import java.awt.datatransfer.Transferable;
import java.awt.event.ActionEvent;
import java.io.Serializable;
import javax.swing.AbstractAction;
import javax.swing.Action;
import org.netbeans.api.project.Project;
import org.netbeans.core.api.multiview.MultiViews;
import org.netbeans.spi.project.ui.support.CommonProjectActions;
import org.openide.nodes.FilterNode;
import org.openide.nodes.Node;
import org.openide.util.HelpCtx;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;
import org.openide.util.datatransfer.PasteType;
import org.openide.util.lookup.Lookups;
import org.openide.util.lookup.ProxyLookup;
import org.openide.windows.TopComponent;

/**
 * Stock root node that appears under Farm-node
 * @author Gerben Feenstra
 */
public final class StockRootNode extends FilterNode implements Serializable {

    private static final String STOCK_NODE_NAME = "Stock";

    public StockRootNode(Node node, Project project) {
        super(node, Children.LEAF, new ProxyLookup(Lookups.singleton(project), node.getLookup()));
    }

    @Override
    public Action[] getActions(boolean arg0) {
        return new Action[]{
            new OpenStockDetailsAction()
        };
    }

    @Override
    public Image getIcon(int type) {
        return ImageUtilities.loadImage(Stock.STOCK_ICON16);
    }

    @Override
    public Image getOpenedIcon(int type) {
        return getIcon(type);
    }

    @Override
    public String getDisplayName() {
        return STOCK_NODE_NAME;
    }

    @Override
    public String getHtmlDisplayName() {
        return getDisplayName();
    }

    @Override
    public HelpCtx getHelpCtx() {
        return new HelpCtx("nl.cloudfarming.client.stock.about");
    }

    @Override
    public PasteType getDropType(Transferable t, int action, int index) {
        return null;
    }

    @NbBundle.Messages(value = "Stock open details action name=Open")
    private final class OpenStockDetailsAction extends AbstractAction {
        public OpenStockDetailsAction() {
            super(Bundle.Stock_open_details_action_name());
        }

        @Override
        public void actionPerformed(ActionEvent e) {
            TopComponent tc = MultiViews.createMultiView(Stock.MIME_TYPE, StockRootNode.this);
            tc.open();
            tc.requestActive();
        }
    }
}
