/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.stock.api;

import java.io.IOException;
import org.netbeans.api.project.Project;
import org.netbeans.spi.project.ui.support.NodeFactory;
import org.netbeans.spi.project.ui.support.NodeFactorySupport;
import org.netbeans.spi.project.ui.support.NodeList;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataFolder;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;

/**
 * NodeFactory registration for Farm projects Will search for STOCK_FOLDER_NAME
 * inside the specified (Farm) project
 *
 * @author Gerben Feenstra
 */
public class StockRootNodeFactory implements NodeFactory {

    @Override
    public NodeList createNodes(Project project) {

        FileObject stockFolder = getStockFolder(project);

        // Create Stock folder if it doesn't exist
        if (stockFolder == null) {
            try {
                stockFolder = project.getProjectDirectory().createFolder(Stock.STOCK_FOLDER_NAME);
            } catch (IOException ex) {
                Exceptions.printStackTrace(ex);
            }
        }
        assert (stockFolder != null);

        DataFolder stockDataFolder = DataFolder.findFolder(stockFolder);
        Node rootNode = new StockRootNode(stockDataFolder.getNodeDelegate(), project);
        return NodeFactorySupport.fixedNodeList(rootNode);
    }
    
    /**
     * Returns stockfolder inside the specified project
     * Protected for unittesting purposes!
     * @param project Project to get stockfolder from.
     * @return Stockfolder on the filesystem
     */
    protected FileObject getStockFolder(Project project){
        return project.getProjectDirectory().getFileObject(Stock.STOCK_FOLDER_NAME);
    }
}
